This is a package I developed for handling paths and file I/O for larger projects. 

The goal is to simplify working with many datasets and 3rd party codebases across different naming conventions, data types, and storage systems. 

To run unit tests, run 

```
$python -m unittest discover -s tests


$for dev, it is better to run pip install -e .
```